@@ -19,7 +19,7 @@ function sent_conf_options() {
    global $sent_conf_allow_user_override, $sent_conf_message_style,
           $sent_conf_include_recip_addr, $sent_conf_show_only_first_recip_addr,
           $username, $data_dir, $sent_conf_include_cc, $sent_conf_include_bcc,
-          $sent_conf_show_headers;
+          $sent_conf_show_headers, $sent_conf_enable_orig_msg_options;
 
    if (compatibility_check_sm_version(1, 3))
       include_once (SM_PATH . 'plugins/sent_confirmation/config.php');
@@ -35,6 +35,7 @@ function sent_conf_options() {
    $sent_conf_include_cc = getPref($data_dir, $username, 'sent_conf_include_cc', $sent_conf_include_cc);
    $sent_conf_include_bcc = getPref($data_dir, $username, 'sent_conf_include_bcc', $sent_conf_include_bcc);
    $sent_conf_show_headers = getPref($data_dir, $username, 'sent_conf_show_headers', $sent_conf_show_headers);
+   $sent_conf_enable_orig_msg_options = getPref($data_dir, $username, 'sent_conf_enable_orig_msg_options', $sent_conf_enable_orig_msg_options);
 
    echo "<TR><TD COLSPAN=\"2\">&nbsp;</TD></TR>\n"
       . "<TR><TD ALIGN=CENTER VALIGN=MIDDLE COLSPAN=2 NOWRAP><B>"
@@ -110,6 +111,16 @@ function sent_conf_options() {
    echo ">&nbsp;" . _("No") . "\n".
       "</td></tr>\n";
 
+   echo "<tr><td align=right valign=top>\n".
+      _("Enable Original Message Options:") . "</td>\n".
+      "<td><input type='radio' value='1' name='sent_conf_enable_orig_msg_options' ";
+   if ($sent_conf_enable_orig_msg_options == '1') echo "CHECKED";
+   echo ">&nbsp;" . _("Yes") . "\n".
+      "&nbsp;&nbsp;&nbsp;&nbsp;<input type='radio' value='0' name='sent_conf_enable_orig_msg_options' ";
+   if ($sent_conf_enable_orig_msg_options == '0') echo "CHECKED";
+   echo ">&nbsp;" . _("No") . "\n".
+      "</td></tr>\n";
+
 }
 
 
@@ -119,7 +130,7 @@ function sent_conf_options_save() {
    global $sent_conf_allow_user_override, $username, $data_dir,
           $sent_conf_style, $sent_conf_incl_recip, $sent_conf_include_cc,
           $sent_conf_show_only_first_recip_addr, $sent_conf_include_bcc,
-          $sent_conf_show_headers;
+          $sent_conf_show_headers, $sent_conf_enable_orig_msg_options;
 
    if (compatibility_check_sm_version(1, 3))
       include_once (SM_PATH . 'plugins/sent_confirmation/config.php');
@@ -135,6 +146,7 @@ function sent_conf_options_save() {
    compatibility_sqextractGlobalVar('sent_conf_include_cc');
    compatibility_sqextractGlobalVar('sent_conf_include_bcc');
    compatibility_sqextractGlobalVar('sent_conf_show_headers');
+   compatibility_sqextractGlobalVar('sent_conf_enable_orig_msg_options');
 
    setPref($data_dir, $username, 'sent_conf_style', $sent_conf_style);
    setPref($data_dir, $username, 'sent_conf_incl_recip', $sent_conf_incl_recip);
@@ -142,6 +154,7 @@ function sent_conf_options_save() {
    setPref($data_dir, $username, 'sent_conf_include_cc', $sent_conf_include_cc);
    setPref($data_dir, $username, 'sent_conf_include_bcc', $sent_conf_include_bcc);
    setPref($data_dir, $username, 'sent_conf_show_headers', $sent_conf_show_headers);
+   setPref($data_dir, $username, 'sent_conf_enable_orig_msg_options', $sent_conf_enable_orig_msg_options);
 
 }
 
@@ -156,7 +169,13 @@ function sent_conf_message_sent_do() {
           $sent_conf_show_only_first_recip_addr, 
           $sent_conf_allow_user_override, $data_dir, $username,
           $sent_conf_include_cc, $sent_conf_include_bcc,
-          $sent_conf_message_style, $sent_conf_show_headers;
+          $sent_conf_message_style, $sent_conf_show_headers,
+          $mailbox, $passed_id, $action, $sort, $sent_conf_orig_reply_msg,
+          $username, $imapServerAddress, $key, $imapPort, $sent_conf_orig_subject,
+          $sent_conf_orig_sender, $sent_conf_enable_orig_msg_options, 
+          $lastTargetMailbox, $sent_conf_mbox_list;
+
+   compatibility_sqextractGlobalVar('lastTargetMailbox');
 
    if (compatibility_check_sm_version(1, 3))
       include_once (SM_PATH . 'plugins/sent_confirmation/config.php');
@@ -171,6 +190,7 @@ function sent_conf_message_sent_do() {
       $sent_conf_include_cc = getPref($data_dir, $username, 'sent_conf_include_cc', $sent_conf_include_cc);
       $sent_conf_include_bcc = getPref($data_dir, $username, 'sent_conf_include_bcc', $sent_conf_include_bcc);
       $sent_conf_show_headers = getPref($data_dir, $username, 'sent_conf_show_headers', $sent_conf_show_headers);
+      $sent_conf_enable_orig_msg_options = getPref($data_dir, $username, 'sent_conf_enable_orig_msg_options', $sent_conf_enable_orig_msg_options);
    }
 
    $sent_conf_message_sent_status = 'sent';
@@ -213,6 +233,47 @@ function sent_conf_message_sent_do() {
       }
    }
 
+
+   // get reply info for deletion, move, back-to options
+   //
+   $sent_conf_orig_reply_msg = '';
+   $sent_conf_orig_subject = '';
+   $sent_conf_orig_sender = '';
+   $sent_conf_mbox_list = '';
+   if ($sent_conf_enable_orig_msg_options && strpos($action, 'reply') !== FALSE)
+   {
+      $sent_conf_orig_reply_msg = $mailbox . '|' . $passed_id . '|' . $sort;
+
+      $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
+      sqimap_mailbox_select($imapConnection, $mailbox);
+      $message = sqimap_get_message($imapConnection, $passed_id, $mailbox);
+      $header = $message->rfc822_header;
+
+      $sent_conf_orig_subject = decodeHeader($header->subject,false,true);
+
+      $orig_from = (is_array($header->from)) ? $header->from[0] : $header->from;
+      if (is_object($orig_from)) {
+         $sent_conf_orig_sender = $orig_from->getAddress();
+      } else {
+         $sent_conf_orig_sender = '';
+      }
+
+      $sent_conf_mbox_list = sqimap_mailbox_option_list($imapConnection, 
+                                                        array(strtolower($lastTargetMailbox)));
+
+// TODO: Thjis just committed functionality to have the correct startMessage when sending
+//       replies... get that here...
+   }
+
+
+   compatibility_sqsession_register($sent_conf_orig_sender, 
+                                    'sent_conf_orig_sender');
+   compatibility_sqsession_register($sent_conf_orig_subject, 
+                                    'sent_conf_orig_subject');
+   compatibility_sqsession_register($sent_conf_orig_reply_msg, 
+                                    'sent_conf_orig_reply_msg');
+   compatibility_sqsession_register($sent_conf_mbox_list, 
+                                    'sent_conf_mbox_list');
    compatibility_sqsession_register($sent_conf_message_sent_status, 
                                     'sent_conf_message_sent_status');
 
@@ -235,9 +296,16 @@ function sent_conf_check_is_sent_do() {
    global $sent_conf_message_sent_status, $color, $sent_confirmation_debug, 
           $sent_conf_message_style, $sent_conf_include_recip_addr, 
           $sent_conf_allow_user_override, $data_dir, $username,
-          $sent_conf_show_headers;
+          $sent_conf_show_headers, $sent_conf_orig_reply_msg,
+          $sent_conf_orig_subject, $sent_conf_orig_sender, 
+          $sent_conf_enable_orig_msg_options, $compose_new_win,
+          $sent_conf_mbox_list;
 
    compatibility_sqextractGlobalVar('sent_conf_message_sent_status');
+   compatibility_sqextractGlobalVar('sent_conf_orig_reply_msg');
+   compatibility_sqextractGlobalVar('sent_conf_orig_subject');
+   compatibility_sqextractGlobalVar('sent_conf_orig_sender');
+   compatibility_sqextractGlobalVar('sent_conf_mbox_list');
 
    if (compatibility_check_sm_version(1, 3))
       include_once (SM_PATH . 'plugins/sent_confirmation/config.php');
@@ -249,6 +317,7 @@ function sent_conf_check_is_sent_do() {
       $sent_conf_message_style = getPref($data_dir, $username, 'sent_conf_style', $sent_conf_message_style);
       $sent_conf_include_recip_addr = getPref($data_dir, $username, 'sent_conf_incl_recip', $sent_conf_include_recip_addr);
       $sent_conf_show_headers = getPref($data_dir, $username, 'sent_conf_show_headers', $sent_conf_show_headers);
+      $sent_conf_enable_orig_msg_options = getPref($data_dir, $username, 'sent_conf_enable_orig_msg_options', $sent_conf_enable_orig_msg_options);
    }
 
    if ($sent_confirmation_debug == 2)
@@ -308,16 +377,26 @@ function sent_conf_check_is_sent_do() {
                 $sent_logo, $sent_logo_width, $sent_logo_height;
          $urlMailbox = urlencode($mailbox);
 
+
          echo '<TABLE CELLSPACING="0" WIDTH="100%" BORDER="0" ALIGN="CENTER" CELLPADDING="0">' 
             . '<TR><TD BGCOLOR="' . $color[9] . '" WIDTH="100%">' 
             . '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="LEFT" WIDTH="100%">' 
-            . '<SMALL>' 
-            . '<A HREF="' . $base_uri . 'src/'
-            . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
-            . _("Message List") . '</A></SMALL>' 
-            . '</TD></TR></TABLE>'
+            . '<SMALL>';
+         if ($compose_new_win)
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "compose.php?newmessage=1\">"
+               . _("Compose") . '</A></SMALL>';
+         }
+         else
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
+               . _("Message List") . '</A></SMALL>';
+         }
+         echo '</TD></TR></TABLE>'
             . '</TD></TR><TR><TD>';
 
 
@@ -335,7 +414,7 @@ function sent_conf_check_is_sent_do() {
                echo ' height="' . $sent_logo_height . '"';
             echo '></td></tr>'. "\n"; 
          }
-         echo '<tr><td align="center"><form action="../plugins/sent_confirmation/address_book_import.php" method="POST" onSubmit="if (document.forms[0].elements.length == 2) { document.forms[0].elements[0].checked=true; return true;} okToSubmit=false; for (i=0; i<document.forms[0].elements.length; i++){if (document.forms[0].elements[i].type == \'checkbox\') if (document.forms[0].elements[i].checked) okToSubmit=true} if (!okToSubmit) alert(\'' . _("Please select an address to add to your address book.") . '\'); return okToSubmit"><strong>'. "\n" 
+         echo '<tr><td align="center"><form name="sent_conf_form" action="../plugins/sent_confirmation/address_book_import.php" method="POST" onSubmit="if (document.sent_conf_form.elements.length == 2) { document.sent_conf_form.elements[0].checked=true; return true;} okToSubmit=false; for (i=0; i<document.sent_conf_form.elements.length; i++){if (document.sent_conf_form.elements[i].type == \'checkbox\') if (document.sent_conf_form.elements[i].checked) okToSubmit=true} if (!okToSubmit) alert(\'' . _("Please select an address to add to your address book.") . '\'); return okToSubmit"><strong>'. "\n" 
             . _("Message Sent To:") . '</strong></td></tr>'."\n"
             . '<tr><td align=center><table border=0 cellspacing=0 cellpadding=0>'."\n";
           
@@ -375,21 +454,121 @@ function sent_conf_check_is_sent_do() {
 
          echo '</table>'
             . '<br><input type=submit value="' . _("Add To Address Book")
-            . '"></form></td></tr></table>'
+            . '"></form>';
+
+         // if is reply, offer deletion of original message here
+         //
+         if ($sent_conf_enable_orig_msg_options && isset($sent_conf_orig_reply_msg) && !empty($sent_conf_orig_reply_msg))
+         {
+
+            list($mailbox, $passed_id, $sort) = explode('|', $sent_conf_orig_reply_msg);
+
+
+            //echo '<table><tr><td><small>' . _("Original Message") . ':</small></td><td><small>' 
+               //. $sent_conf_orig_subject 
+               //. '</small></td></tr><tr><td>&nbsp;</td><td><small><a href="../src/delete_message.php?mailbox=' 
+               //. $mailbox . '&message=' . $passed_id . '&sort=' . $sort . '&startMessage=1">'
+               //. _("Delete") . '</a><small></td></tr></table>';
+
+
+            //echo '<small><a href="../src/delete_message.php?mailbox=' . $mailbox . '&message=' 
+               //. $passed_id . '&sort=' . $sort . '&startMessage=1">' 
+               //. _("Delete Original Message") . '</a><br>' . _("Subject") . ': ' 
+               //. $sent_conf_orig_subject . '</small>';
+
+
+// this one looked nice (only delete link)
+            //echo '<table><tr><td colspan="2" align="center"><small><a href="../src/delete_message.php?mailbox=' 
+               //. $mailbox . '&message=' . $passed_id . '&sort=' . $sort . '&startMessage=1">' 
+               //. _("Delete Original Message") . '</a></small></td></tr><tr><td align="right"><small><strong>' . _("From") 
+               //. ':</strong></small></td><td><small>' . $sent_conf_orig_sender . '</small></td></tr><tr><td align="right"><small><strong>'
+               //. _("Subject") . ':</strong></small></td><td><small>' 
+               //. $sent_conf_orig_subject . '</small></td></tr></table>';
+
+
+            $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+            $form_name = "FormMsgs" . $safe_name;
+
+            echo '<form name="' . $form_name . '" method="post" action="../src/move_messages.php">' . "\n"
+               . '<input type="hidden" name="mailbox" value="' . htmlspecialchars($mailbox) . '">'
+               . '<input type="hidden" name="sort" value="' . $sort . '">'
+               . '<input type="hidden" name="msg" value="">'
+               . '<input type="hidden" name="msg[0]" value="' . $passed_id . '">'
+               . '<input type="hidden" name="location" value="'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox"
+               . '">'
+
+// TODO: Thjis just committed a fix to DEVEL that allows the start message to be correct
+//       when having sent a reply... we should get and use that here...
+////               . '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">'
+// and then delete this line:
+. '<input type="hidden" name="startMessage" value="1">'
+
+               . "\n"
+               . '<table><tr><td colspan="2" align="center"><small><strong>' . _("Original Message") 
+               . '<strong></small><hr></td></tr><tr><td align="right"><small><strong>' . _("From") 
+               . ':</strong></small></td><td><small>' . $sent_conf_orig_sender . '</small></td></tr><tr><td align="right"><small><strong>'
+               . _("Subject") . ':</strong></small></td><td><small>' 
+               . $sent_conf_orig_subject . '</small></td></tr>'
+////               . '<tr><td colspan="2" align="center"><hr></td></tr>'
+               . '<tr><td colspan="2" align="center"><small><br><a href="../src/delete_message.php?mailbox='
+               . $mailbox . '&message=' . $passed_id . '&sort=' . $sort 
+               . '&startMessage=1">Delete</a> | <a href="../src/read_body.php?mailbox='
+               . $mailbox . '&passed_id=' . $passed_id 
+               . '&startMessage=1">Return To Message</a></small>'
+               . '</td></tr><tr><td align="center" colspan="2"><small>' 
+               . _("Move to:") . ' <select name="targetMailbox">' . $sent_conf_mbox_list
+               . '</SELECT>&nbsp;'
+               . getButton('SUBMIT', 'moveButton', _("Move")) . "\n"
+. ""
+               . '</small></td></tr>'
+               . '</table></form>';
+
+// read links as constructed in mailbox_display.php
+// but stuff like startMessage and searchstr don't
+// appear to be available after the send button is 
+// pressed
+//
+//<a href="read_body.php?mailbox='.$urlMailbox
+//  .  '&amp;passed_id='. $msg["ID"]
+//  .  '&amp;startMessage='.$start_msg.$searchstr.'"';
+//  $td_str .= ' ' .concat_hook_function('subject_link', array($start_msg, $searchstr));
+//  if ($subject != $msg['SUBJECT']) {
+//  $title = get_html_translation_table(HTML_SPECIALCHARS);
+//  $title = array_flip($title);
+//  $title = strtr($msg['SUBJECT'], $title);
+//  $title = str_replace('"', "''", $title);
+//  $td_str .= " title=\"$title\"";
+//  }
+//  $td_str .= ">
+
+         }
+
+         echo '</td></tr></table>'
             . '</td></tr></table>';
 
          echo '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="RIGHT" WIDTH="100%"><br>' 
-            . '<SMALL>' 
-            . '<A HREF="' . $base_uri . 'src/'
-            . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
-            . _("Message List") . '</A></SMALL>' 
-            . '</TD></TR></TABLE></TD></TR></TABLE>';
+            . '<SMALL>';
+         if ($compose_new_win)
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "compose.php?newmessage=1\">"
+               . _("Compose") . '</A></SMALL>';
+         }
+         else
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
+               . _("Message List") . '</A></SMALL>';
+         }
+         echo '</TD></TR></TABLE></TD></TR></TABLE>';
 
          echo '</td></tr></table>'
             . '</body></html>';
 
+//global $username; if ($username == 'paul@angrynerds.com') exit;
          $sent_conf_message_sent_status = 'not_sent';
          compatibility_sqsession_register($sent_conf_message_sent_status, 
                                           'sent_conf_message_sent_status');
@@ -411,11 +590,20 @@ function sent_conf_check_is_sent_do() {
             . '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="LEFT" WIDTH="100%">' 
-            . '<SMALL>' 
-            . '<A HREF="' . $base_uri . 'src/'
-            . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
-            . _("Message List") . '</A></SMALL>' 
-            . '</TD></TR></TABLE>'
+            . '<SMALL>';
+         if ($compose_new_win)
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "compose.php?newmessage=1\">"
+               . _("Compose") . '</A></SMALL>';
+         }
+         else
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
+               . _("Message List") . '</A></SMALL>';
+         }
+         echo '</TD></TR></TABLE>'
             . '</TD></TR><TR><TD>';
 
 
@@ -466,17 +654,117 @@ function sent_conf_check_is_sent_do() {
          }
 
          echo '</table>'
-            . '<br></td></tr></table>'
-            . '</td></tr></table>';
+            . '<br>';
 
+
+         // if is reply, offer deletion of original message here
+         //
+         if ($sent_conf_enable_orig_msg_options && isset($sent_conf_orig_reply_msg) && !empty($sent_conf_orig_reply_msg))
+         {
+
+            list($mailbox, $passed_id, $sort) = explode('|', $sent_conf_orig_reply_msg);
+
+
+            //echo '<table><tr><td><small>' . _("Original Message") . ':</small></td><td><small>' 
+               //. $sent_conf_orig_subject 
+               //. '</small></td></tr><tr><td>&nbsp;</td><td><small><a href="../src/delete_message.php?mailbox=' 
+               //. $mailbox . '&message=' . $passed_id . '&sort=' . $sort . '&startMessage=1">'
+               //. _("Delete") . '</a><small></td></tr></table>';
+
+
+            //echo '<small><a href="../src/delete_message.php?mailbox=' . $mailbox . '&message=' 
+               //. $passed_id . '&sort=' . $sort . '&startMessage=1">' 
+               //. _("Delete Original Message") . '</a><br>' . _("Subject") . ': ' 
+               //. $sent_conf_orig_subject . '</small>';
+
+
+// this one looked nice (only delete link)
+            //echo '<table><tr><td colspan="2" align="center"><small><a href="../src/delete_message.php?mailbox=' 
+               //. $mailbox . '&message=' . $passed_id . '&sort=' . $sort . '&startMessage=1">' 
+               //. _("Delete Original Message") . '</a></small></td></tr><tr><td align="right"><small><strong>' . _("From") 
+               //. ':</strong></small></td><td><small>' . $sent_conf_orig_sender . '</small></td></tr><tr><td align="right"><small><strong>'
+               //. _("Subject") . ':</strong></small></td><td><small>' 
+               //. $sent_conf_orig_subject . '</small></td></tr></table>';
+
+
+            $safe_name = preg_replace("/[^0-9A-Za-z_]/", '_', $mailbox);
+            $form_name = "FormMsgs" . $safe_name;
+
+            echo '<form name="' . $form_name . '" method="post" action="../src/move_messages.php">' . "\n"
+               . '<input type="hidden" name="mailbox" value="' . htmlspecialchars($mailbox) . '">'
+               . '<input type="hidden" name="sort" value="' . $sort . '">'
+               . '<input type="hidden" name="msg" value="">'
+               . '<input type="hidden" name="msg[0]" value="' . $passed_id . '">'
+               . '<input type="hidden" name="location" value="'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox"
+               . '">'
+
+// TODO: Thjis just committed a fix to DEVEL that allows the start message to be correct
+//       when having sent a reply... we should get and use that here...
+////               . '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">'
+// and then delete this line:
+. '<input type="hidden" name="startMessage" value="1">'
+
+               . "\n"
+               . '<table><tr><td colspan="2" align="center"><small><strong>' . _("Original Message") 
+               . '<strong></small><hr></td></tr><tr><td align="right"><small><strong>' . _("From") 
+               . ':</strong></small></td><td><small>' . $sent_conf_orig_sender . '</small></td></tr><tr><td align="right"><small><strong>'
+               . _("Subject") . ':</strong></small></td><td><small>' 
+               . $sent_conf_orig_subject . '</small></td></tr>'
+////               . '<tr><td colspan="2" align="center"><hr></td></tr>'
+               . '<tr><td colspan="2" align="center"><small><br><a href="../src/delete_message.php?mailbox='
+               . $mailbox . '&message=' . $passed_id . '&sort=' . $sort 
+               . '&startMessage=1">Delete</a> | <a href="../src/read_body.php?mailbox='
+               . $mailbox . '&passed_id=' . $passed_id 
+               . '&startMessage=1">Return To Message</a></small>'
+               . '</td></tr><tr><td align="center" colspan="2"><small>' 
+               . _("Move to:") . ' <select name="targetMailbox">' . $sent_conf_mbox_list
+               . '</SELECT>&nbsp;'
+               . getButton('SUBMIT', 'moveButton', _("Move")) . "\n"
+. ""
+               . '</small></td></tr>'
+               . '</table></form>';
+
+// read links as constructed in mailbox_display.php
+// but stuff like startMessage and searchstr don't
+// appear to be available after the send button is 
+// pressed
+//
+//<a href="read_body.php?mailbox='.$urlMailbox
+//  .  '&amp;passed_id='. $msg["ID"]
+//  .  '&amp;startMessage='.$start_msg.$searchstr.'"';
+//  $td_str .= ' ' .concat_hook_function('subject_link', array($start_msg, $searchstr));
+//  if ($subject != $msg['SUBJECT']) {
+//  $title = get_html_translation_table(HTML_SPECIALCHARS);
+//  $title = array_flip($title);
+//  $title = strtr($msg['SUBJECT'], $title);
+//  $title = str_replace('"', "''", $title);
+//  $td_str .= " title=\"$title\"";
+//  }
+//  $td_str .= ">
+
+         }
+
+
+         echo '</td></tr></table>'
+            . '</td></tr></table>';
          echo '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="RIGHT" WIDTH="100%"><br>' 
-            . '<SMALL>' 
-            . '<A HREF="' . $base_uri . 'src/'
-            . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
-            . _("Message List") . '</A></SMALL>' 
-            . '</TD></TR></TABLE></TD></TR></TABLE>';
+            . '<SMALL>';
+         if ($compose_new_win)
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "compose.php?newmessage=1\">"
+               . _("Compose") . '</A></SMALL>';
+         }
+         else
+         {
+            echo '<A HREF="' . $base_uri . 'src/'
+               . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox\">"
+               . _("Message List") . '</A></SMALL>';
+         }
+         echo '</TD></TR></TABLE></TD></TR></TABLE>';
 
          echo '</td></tr></table>'
             . '</body></html>';
@@ -500,7 +788,7 @@ function sent_conf_check_is_sent_do() {
 
 
 
-//
+// clear out sent indicator
 //
 function sent_conf_compose_bottom_do() {
 
